==> Decorative%20Food-1.20.1-1.0.8-sources.jar: org/dfood/mixin/ServerPlayerInteractionManagerMixin.java <==
package org.dfood.mixin;

import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_174;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_3222;
import net.minecraft.class_3225;
import net.minecraft.class_3965;
import org.dfood.util.DFoodUtils;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_3225.class)
public class ServerPlayerInteractionManagerMixin {

    /**
     *该类是为了优化食物放置手感而设计的，
     * 即使玩家下蹲也能与食物方块交互。
     */
    @Inject(method = "interactBlock", at = @At(value = "INVOKE", target = "Lnet/minecraft/item/ItemStack;copy()Lnet/minecraft/item/ItemStack;"), cancellable = true)
    private void interactBlockMixin(class_3222 player, class_1937 world, class_1799 stack, class_1268 hand, class_3965 hitResult, CallbackInfoReturnable<class_1269> cir){
        boolean bl3 = DFoodUtils.isModFoodItem(player.method_6047().method_7909());
        if (bl3) {
            class_2338 blockPos = hitResult.method_17777();
            class_2680 blockState = world.method_8320(blockPos);
            class_1269 actionResult = blockState.method_26174(world, player, hand, hitResult);
            class_1799 itemStack = stack.method_7972();
            if (actionResult.method_23665()) {
                class_174.field_24478.method_23889(player, blockPos, itemStack);
                cir.setReturnValue(actionResult);
            }
        }
    }
}

==> Decorative%20Food-1.21.5-1.0.5-sources.jar: org/dfood/mixin/ServerPlayerInteractionManagerMixin.java <==
package org.dfood.mixin;

import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_174;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_3222;
import net.minecraft.class_3225;
import net.minecraft.class_3965;
import org.dfood.util.DFoodUtils;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_3225.class)
public class ServerPlayerInteractionManagerMixin {

    /**
     *该类是为了优化食物放置手感而设计的，
     * 即使玩家下蹲也能与食物方块交互。
     */
    @Inject(method = "interactBlock", at = @At(value = "INVOKE", target = "Lnet/minecraft/item/ItemStack;copy()Lnet/minecraft/item/ItemStack;"), cancellable = true)
    private static void interactBlockMixin(class_3222 player, class_1937 world, class_1799 stack, class_1268 hand, class_3965 hitResult, CallbackInfoReturnable<class_1269> cir){
        boolean bl3 = DFoodUtils.isModFoodItem(player.method_6047().method_7909());
        if (bl3) {
            class_2338 blockPos = hitResult.method_17777();
            class_2680 blockState = world.method_8320(blockPos);
            class_1269 actionResult = blockState.method_55781(world, player, hitResult);
            class_1799 itemStack = stack.method_7972();
            if (actionResult.method_23665()) {
                class_174.field_24478.method_23889(player, blockPos, itemStack);
                cir.setReturnValue(actionResult);
            }
        }
    }
}
